==> jc-1.4.0.tar.gz: gnu/java/util/EmptyEnumeration.h <==
// public final class gnu.java.util.EmptyEnumeration

// class file dependencies
// @dep_class 2c2d9b19a117be28 gnu_java_util_EmptyEnumeration
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_EmptyEnumeration_H_
#define _JC_gnu_java_util_EmptyEnumeration_H_

// Forward structure declarations
struct _jc_gnu_java_util_EmptyEnumeration$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_util_EmptyEnumeration$sub_refs	_jc_gnu_java_util_EmptyEnumeration$sub_refs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$sub_nonrefs	_jc_gnu_java_util_EmptyEnumeration$sub_nonrefs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$refs	_jc_gnu_java_util_EmptyEnumeration$refs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$nonrefs	_jc_gnu_java_util_EmptyEnumeration$nonrefs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$object	_jc_gnu_java_util_EmptyEnumeration$object;

typedef struct _jc_gnu_java_util_EmptyEnumeration$fields_struct	_jc_gnu_java_util_EmptyEnumeration$fields_struct;
typedef const struct _jc_gnu_java_util_EmptyEnumeration$vmethods	_jc_gnu_java_util_EmptyEnumeration$vmethods;
typedef const struct _jc_gnu_java_util_EmptyEnumeration$vtable	_jc_gnu_java_util_EmptyEnumeration$vtable;
typedef const struct _jc_gnu_java_util_EmptyEnumeration$vtype	_jc_gnu_java_util_EmptyEnumeration$vtype;

// Class fields structure
struct _jc_gnu_java_util_EmptyEnumeration$fields_struct {
	struct _jc_gnu_java_util_EmptyEnumeration$object	*instance;
};
extern _jc_gnu_java_util_EmptyEnumeration$fields_struct _jc_gnu_java_util_EmptyEnumeration$class_fields;

// Constructors
extern void _jc_gnu_java_util_EmptyEnumeration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *);

// Virtual methods
extern jboolean _jc_gnu_java_util_EmptyEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_util_EmptyEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_EmptyEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_gnu_java_util_EmptyEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Static methods
extern void _jc_gnu_java_util_EmptyEnumeration$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_gnu_java_util_EmptyEnumeration$object *_jc_gnu_java_util_EmptyEnumeration$method$getInstance$0d26b7a0d154ae80(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_util_EmptyEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *);
};

// Vtable
struct _jc_gnu_java_util_EmptyEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_EmptyEnumeration$vmethods	gnu_java_util_EmptyEnumeration;
};

// Vtype
struct _jc_gnu_java_util_EmptyEnumeration$vtype {
	_jc_type			type;
	_jc_gnu_java_util_EmptyEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_EmptyEnumeration$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_util_EmptyEnumeration$refs {
    _jc_gnu_java_util_EmptyEnumeration$sub_refs	gnu_java_util_EmptyEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_EmptyEnumeration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_EmptyEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_EmptyEnumeration$sub_nonrefs	gnu_java_util_EmptyEnumeration;
};

// Object instance structure
struct _jc_gnu_java_util_EmptyEnumeration$object {
	_jc_gnu_java_util_EmptyEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_EmptyEnumeration$vtype	*vtype;
	_jc_gnu_java_util_EmptyEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_EmptyEnumeration$vtype _jc_gnu_java_util_EmptyEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_EmptyEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_EmptyEnumeration$class_object;

#endif	/* _JC_gnu_java_util_EmptyEnumeration_H_ */

==> jc-1.4.6.tar.gz: gnu/java/util/EmptyEnumeration.h <==
// public final class gnu.java.util.EmptyEnumeration

// class file dependencies
// @dep_class 2c2d9b19a117be28 gnu_java_util_EmptyEnumeration
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_EmptyEnumeration_H_
#define _JC_gnu_java_util_EmptyEnumeration_H_

// Forward structure declarations
struct _jc_gnu_java_util_EmptyEnumeration$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_util_EmptyEnumeration$sub_refs	_jc_gnu_java_util_EmptyEnumeration$sub_refs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$sub_nonrefs	_jc_gnu_java_util_EmptyEnumeration$sub_nonrefs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$refs	_jc_gnu_java_util_EmptyEnumeration$refs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$nonrefs	_jc_gnu_java_util_EmptyEnumeration$nonrefs;
typedef struct _jc_gnu_java_util_EmptyEnumeration$object	_jc_gnu_java_util_EmptyEnumeration$object;

typedef struct _jc_gnu_java_util_EmptyEnumeration$fields_struct	_jc_gnu_java_util_EmptyEnumeration$fields_struct;
typedef const struct _jc_gnu_java_util_EmptyEnumeration$vmethods	_jc_gnu_java_util_EmptyEnumeration$vmethods;
typedef const struct _jc_gnu_java_util_EmptyEnumeration$vtable	_jc_gnu_java_util_EmptyEnumeration$vtable;
typedef const struct _jc_gnu_java_util_EmptyEnumeration$vtype	_jc_gnu_java_util_EmptyEnumeration$vtype;

// Class fields structure
struct _jc_gnu_java_util_EmptyEnumeration$fields_struct {
	struct _jc_gnu_java_util_EmptyEnumeration$object	*instance;
};
extern _jc_gnu_java_util_EmptyEnumeration$fields_struct _jc_gnu_java_util_EmptyEnumeration$class_fields;

// Constructors
extern void _jc_gnu_java_util_EmptyEnumeration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_util_EmptyEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_util_EmptyEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_EmptyEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_gnu_java_util_EmptyEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Static methods
extern void _jc_gnu_java_util_EmptyEnumeration$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_util_EmptyEnumeration$object *_jc_gnu_java_util_EmptyEnumeration$method$getInstance$0d26b7a0d154ae80(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_util_EmptyEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_gnu_java_util_EmptyEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_util_EmptyEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_EmptyEnumeration$vmethods	gnu_java_util_EmptyEnumeration;
};

// Vtype
struct _jc_gnu_java_util_EmptyEnumeration$vtype {
	_jc_type			type;
	_jc_gnu_java_util_EmptyEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_EmptyEnumeration$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_util_EmptyEnumeration$refs {
    _jc_gnu_java_util_EmptyEnumeration$sub_refs	gnu_java_util_EmptyEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_EmptyEnumeration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_EmptyEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_EmptyEnumeration$sub_nonrefs	gnu_java_util_EmptyEnumeration;
};

// Object instance structure
struct _jc_gnu_java_util_EmptyEnumeration$object {
	_jc_gnu_java_util_EmptyEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_EmptyEnumeration$vtype	*vtype;
	_jc_gnu_java_util_EmptyEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_EmptyEnumeration$vtype _jc_gnu_java_util_EmptyEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_EmptyEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_EmptyEnumeration$class_object;

#endif	/* _JC_gnu_java_util_EmptyEnumeration_H_ */
